Thanks for contributing to Safir.

Since Safir is intended for internal use by the Vera C. Rubin Observatory, community contributions can only be accepted if they align with the Rubin Observatory's aims.
For that reason, it's a good idea to propose changes with a new GitHub issue before investing time in making a pull request.

For more information about developing Safir, see https://safir.lsst.io/dev/development.html.

See also our [Code of Conduct](./CODE_OF_CONDUCT).
